GIAS3 (Geometry Image-Analysis Statistics) Visualisation
========================================================

The visualisation packages of the GIAS3 libraries.

Make sure that::

  os.environ['ETS_TOOLKIT'] = 'qt'

Is set to the appropriate toolkit.
